@@ -64,7 +64,7 @@ from functools import partial as p
 from importlib import import_module
 
 import pycond
-
+from lcdoc import lprunner as mdr
 from lcdoc.mkdocs.tools import page_dir
 from lcdoc.tools import app, dirname, write_file
 
@@ -72,13 +72,14 @@ from lcdoc.tools import app, dirname, write_file
 I = lambda s: s if not sys.stdout.isatty() else '\x1b[1;32m%s\x1b[0m' % s
 L = lambda s: s if not sys.stdout.isatty() else '\x1b[0;2;38;5;242m%s\x1b[0m' % s
 
+is_lprunner = [0]
 env = os.environ
 wait = time.sleep
 now = time.time
 exists = os.path.exists
-user = env['USER']
+user = env.get('USER', 'root')  # in docker: Key error, else.
 env['PATH'] = 'bin:%s' % env.get('PATH', '')
-
+bash = lambda: os.system('bash')  # debug
 
 _ = lambda f, msg, *a, **kw: f(str(msg) + ' '.join([str(i) for i in a]), **kw)
 dbg = p(_, app.debug)
@@ -149,10 +150,26 @@ def sprun(*a, no_fail=False, report=False, **kw):
             report('', a[0])
         else:
             report('', a, kw)  # for the user (also in view messages)
+    show_res = False
+    if is_lprunner[0]:
+        if isinstance(a[0], str) and not str(a[0]).startswith('tmux'):
+            show_res = True
+            mdr.confirm('Run %s' % ' '.join(a))
 
     c = p(sp.check_output, shell=True, stderr=sp.STDOUT, executable='/bin/bash')
     try:
-        return c(*a, **kw)
+        # a line within bash lp ... has e.g. # pdb -> stop before executing command
+        # so that user can try:
+        if a and isinstance(a[0], str) and ' pdb' in a[0]:
+            print('"pdb" was found, interrupting before calling:')
+            print(a[0])
+            print('type bash()` to get a shell.')
+            breakpoint()  # FIXME BREAKPOINT
+        res = c(*a, **kw)
+        if show_res and res:
+            print('Result:')
+            print(res.decode('utf-8'))
+        return res
     except Exception as ex:
         if not no_fail:
             raise
