@@ -1,10 +1,12 @@
 from . import (
     call_flow_logging,
     comments,
+    convert,
     cov_report,
     data_table,
     diag_diagram,
     git_changelog,
+    lprunner,
     mpl_pyplot,
     project_dependencies,
     screenshot,
